import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.pages;
  const yValue = d => d.book;
  const margin = { top: 40, right: 40, bottom: 50, left: 120 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.1);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  
  g.append('g').call(axisLeft(yScale))
  .selectAll('.domain , .tick line')
  .remove();
  
  g.append('g').call(axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`)
    .append('text')
    .attr('y', 40)
    .attr('x', innerWidth/2)
    .attr('fill','black')
    .attr('class', 'xClass')
    .text('Number of Pages');
  
  g.append('text')
    .attr('y', -10)
    .text('Books by Number of Pages');
  
  g.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth());
};

csv('data.csv').then(data => {
  data.forEach(d => {
    d.pages = +d.pages;
  });
  render(data);
});